cmd

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: MIT Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute is the entrypoint called by main.go.

func GenerateCompletions

func GenerateCompletions(dir string)

GenerateCompletions writes shell completion scripts to the given directory. Called by the generate_completions.go build script during release.

func GenerateManPage

func GenerateManPage(dir string)

GenerateManPage writes man pages for all commands to the given directory. Called by the generate_man.go build script during release.

Types

This section is empty.

Jump to