Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateCompletions ¶
func GenerateCompletions(dir string)
GenerateCompletions writes shell completion scripts to the given directory. Called by the generate_completions.go build script during release.
func GenerateManPage ¶
func GenerateManPage(dir string)
GenerateManPage writes man pages for all commands to the given directory. Called by the generate_man.go build script during release.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.